Description Usage Arguments Value Examples
Function producing the univariate forecasts employing all the benchmark methods of the M4 competition. Adapted from https://github.com/M4Competition/M4-methods/blob/master/Benchmarks%20and%20Evaluation.R
1 | M4_benchmarks(input, fh)
|
input |
|
fh |
|
List containing:
Naive: h-step forecast for the naive method (numeric vector - length h)
NaiveSeasonal: h-step forecast for the seasonal naive method (numeric vector - length h)
SimpleES: h-step forecast for the simple exponential smoothing method (numeric vector - length h)
HoltWinters: h-step forecast for the Holt-Winters method (numeric vector - length h)
HoltWintersDamped: h-step forecast for Holt-Winters damped method (numeric vector - length h)
Theta: h-step forecast for the theta method (numeric vector - length h)
Combined: h-step forecast for the combined method (numeric vector - length h)
TimeNaive: Computational time for the naive method (numeric scalar)
TimeNaiveSeasonal: Computational time for the seasonal naive method (numeric scalar)
TimeSimpleES: Computational time for the simple exponential smoothing method (numeric scalar)
TimeHoltWinters: Computational time for the Holt-Winters method (numeric scalar)
TimeHoltWintersDamped: Computational time for Holt-Winters damped method (numeric scalar)
TimeTheta: Computational time for the theta method (numeric scalar)
TimeCombined: Computational time for the combined method (numeric scalar)
1 2 3 4 5 | x <- AirPassengers
splitting_point <- round(2*length(x)/3)
x_train <- x[1:splitting_point]
h <- 5
univariate_results <- M4_benchmarks(x_train,h)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.