Description Usage Arguments Value
Auxiliary function for computing a statistical test for seasonality From https://github.com/M4Competition/M4-methods/blob/master/Benchmarks%20and%20Evaluation.R
1 | SeasonalityTest(input, ppy)
|
input |
|
ppy |
|
Boolean value describing whether the time series is seasonal or not
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.