input_check_level: input_check_level

Description Usage Arguments Value

View source: R/inputVerification.R

Description

Verifies that the level input to the univariate forecasting function has the correct types and shape

Usage

1

Arguments

level
  • Numeric vector (length 2) containing the upper and lower bound for interval forecasting

Value


jdestefani/MM4Benchmark documentation built on Dec. 20, 2021, 10:05 p.m.