Description Usage Arguments Value Examples
Function producing the multivariate forecasts employing all the benchmark methods of the M4 competition. The multivariate implementation is made by launching in parallel the different univariate M4 benchmarks https://github.com/M4Competition/M4-methods/blob/master/Benchmarks%20and%20Evaluation.R on all the multivariate series
1 | multivariate_M4benchmarks(Xtr, h)
|
Xtr |
|
h |
|
List containing:
Naive: h-step forecast for the naive method (numeric matrix - dimensions h x N)
NaiveSeasonal: h-step forecast for the seasonal naive method (numeric matrix - dimensions h x N)
SimpleES: h-step forecast for the simple exponential smoothing method (numeric matrix - dimensions h x N)
HoltWinters: h-step forecast for the Holt-Winters method (numeric matrix - dimensions h x N)
HoltWintersDamped: h-step forecast for Holt-Winters damped method (numeric matrix - dimensions h x N)
Theta: h-step forecast for the theta method (numeric matrix - dimensions h x N)
Combined: h-step forecast for the combined method (numeric matrix - dimensions h x N)
TimeNaive: Computational time for the naive method (numeric scalar)
TimeNaiveSeasonal: Computational time for the seasonal naive method (numeric scalar)
TimeSimpleES: Computational time for the simple exponential smoothing method (numeric scalar)
TimeHoltWinters: Computational time for the Holt-Winters method (numeric scalar)
TimeHoltWintersDamped: Computational time for Holt-Winters damped method (numeric scalar)
TimeTheta: Computational time for the theta method (numeric scalar)
TimeCombined: Computational time for the combined method (numeric scalar)
1 2 3 4 5 | X <- EuStockMarkets
splitting_point <- round(2*dim(X)[1]/3)
X_train <- X[1:splitting_point,]
h <- 5
multivariate_results <- multivariate_M4benchmarks(X_train,h)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.